# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: Neonize.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'Neonize.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waVnameCert import WAWebProtobufsVnameCert_pb2 as waVnameCert_dot_WAWebProtobufsVnameCert__pb2
from waE2E import WAWebProtobufsE2E_pb2 as waE2E_dot_WAWebProtobufsE2E__pb2
from waWeb import WAWebProtobufsWeb_pb2 as waWeb_dot_WAWebProtobufsWeb__pb2
from waSyncAction import WASyncAction_pb2 as waSyncAction_dot_WASyncAction__pb2
from waHistorySync import WAWebProtobufsHistorySync_pb2 as waHistorySync_dot_WAWebProtobufsHistorySync__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rNeonize.proto\x12\x07neonize\x1a)waVnameCert/WAWebProtobufsVnameCert.proto\x1a\x1dwaE2E/WAWebProtobufsE2E.proto\x1a\x1dwaWeb/WAWebProtobufsWeb.proto\x1a\x1fwaSyncAction/WASyncAction.proto\x1a-waHistorySync/WAWebProtobufsHistorySync.proto\"q\n\x03JID\x12\x0c\n\x04User\x18\x01 \x02(\t\x12\x10\n\x08RawAgent\x18\x02 \x02(\r\x12\x0e\n\x06\x44\x65vice\x18\x03 \x02(\r\x12\x12\n\nIntegrator\x18\x04 \x02(\r\x12\x0e\n\x06Server\x18\x05 \x02(\t\x12\x16\n\x07IsEmpty\x18\x06 \x01(\x08:\x05\x66\x61lse\"\xb1\x02\n\x0bMessageInfo\x12-\n\rMessageSource\x18\x01 \x02(\x0b\x32\x16.neonize.MessageSource\x12\n\n\x02ID\x18\x02 \x02(\t\x12\x10\n\x08ServerID\x18\x03 \x02(\x03\x12\x0c\n\x04Type\x18\x04 \x02(\t\x12\x10\n\x08Pushname\x18\x05 \x02(\t\x12\x11\n\tTimestamp\x18\x06 \x02(\x03\x12\x10\n\x08\x43\x61tegory\x18\x07 \x02(\t\x12\x11\n\tMulticast\x18\x08 \x02(\x08\x12\x11\n\tMediaType\x18\t \x02(\t\x12\x0c\n\x04\x45\x64it\x18\n \x02(\t\x12+\n\x0cVerifiedName\x18\x0b \x01(\x0b\x32\x15.neonize.VerifiedName\x12/\n\x0e\x44\x65viceSentMeta\x18\x0c \x01(\x0b\x32\x17.neonize.DeviceSentMeta\"\x92\x01\n\x0eUploadResponse\x12\x0b\n\x03url\x18\x01 \x02(\t\x12\x12\n\nDirectPath\x18\x02 \x02(\t\x12\x0e\n\x06Handle\x18\x03 \x02(\t\x12\x10\n\x08MediaKey\x18\x04 \x02(\x0c\x12\x15\n\rFileEncSHA256\x18\x05 \x02(\x0c\x12\x12\n\nFileSHA256\x18\x06 \x02(\x0c\x12\x12\n\nFileLength\x18\x07 \x02(\r\"\x96\x01\n\rMessageSource\x12\x1a\n\x04\x43hat\x18\x01 \x02(\x0b\x32\x0c.neonize.JID\x12\x1c\n\x06Sender\x18\x02 \x02(\x0b\x32\x0c.neonize.JID\x12\x10\n\x08IsFromMe\x18\x03 \x02(\x08\x12\x0f\n\x07IsGroup\x18\x04 \x02(\x08\x12(\n\x12\x42roadcastListOwner\x18\x05 \x02(\x0b\x32\x0c.neonize.JID\"7\n\x0e\x44\x65viceSentMeta\x12\x16\n\x0e\x44\x65stinationJID\x18\x01 \x02(\t\x12\r\n\x05Phash\x18\x02 \x02(\t\"\xa0\x01\n\x0cVerifiedName\x12\x45\n\x0b\x43\x65rtificate\x18\x01 \x01(\x0b\x32\x30.WAWebProtobufsVnameCert.VerifiedNameCertificate\x12I\n\x07\x44\x65tails\x18\x02 \x01(\x0b\x32\x38.WAWebProtobufsVnameCert.VerifiedNameCertificate.Details\"{\n\x14IsOnWhatsAppResponse\x12\r\n\x05Query\x18\x01 \x02(\t\x12\x19\n\x03JID\x18\x02 \x02(\x0b\x32\x0c.neonize.JID\x12\x0c\n\x04IsIn\x18\x03 \x02(\x08\x12+\n\x0cVerifiedName\x18\x04 \x01(\x0b\x32\x15.neonize.VerifiedName\"y\n\x08UserInfo\x12+\n\x0cVerifiedName\x18\x01 \x01(\x0b\x32\x15.neonize.VerifiedName\x12\x0e\n\x06Status\x18\x02 \x02(\t\x12\x11\n\tPictureID\x18\x03 \x02(\t\x12\x1d\n\x07\x44\x65vices\x18\x04 \x03(\x0b\x32\x0c.neonize.JID\"s\n\x06\x44\x65vice\x12\x19\n\x03JID\x18\x01 \x01(\x0b\x32\x0c.neonize.JID\x12\x10\n\x08Platform\x18\x02 \x02(\t\x12\x15\n\rBussinessName\x18\x03 \x02(\t\x12\x10\n\x08PushName\x18\x04 \x02(\t\x12\x13\n\x0bInitialized\x18\x05 \x02(\x08\"M\n\tGroupName\x12\x0c\n\x04Name\x18\x01 \x02(\t\x12\x11\n\tNameSetAt\x18\x02 \x02(\x03\x12\x1f\n\tNameSetBy\x18\x03 \x02(\x0b\x32\x0c.neonize.JID\"x\n\nGroupTopic\x12\r\n\x05Topic\x18\x01 \x02(\t\x12\x0f\n\x07TopicID\x18\x02 \x02(\t\x12\x12\n\nTopicSetAt\x18\x03 \x02(\x03\x12 \n\nTopicSetBy\x18\x04 \x02(\x0b\x32\x0c.neonize.JID\x12\x14\n\x0cTopicDeleted\x18\x05 \x02(\x08\"\x1f\n\x0bGroupLocked\x12\x10\n\x08isLocked\x18\x01 \x02(\x08\">\n\rGroupAnnounce\x12\x12\n\nIsAnnounce\x18\x01 \x02(\x08\x12\x19\n\x11\x41nnounceVersionID\x18\x02 \x02(\t\"@\n\x0eGroupEphemeral\x12\x13\n\x0bIsEphemeral\x18\x01 \x02(\x08\x12\x19\n\x11\x44isappearingTimer\x18\x02 \x02(\r\"%\n\x0eGroupIncognito\x12\x13\n\x0bIsIncognito\x18\x01 \x02(\x08\"F\n\x0bGroupParent\x12\x10\n\x08IsParent\x18\x01 \x02(\x08\x12%\n\x1d\x44\x65\x66\x61ultMembershipApprovalMode\x18\x02 \x02(\t\":\n\x11GroupLinkedParent\x12%\n\x0fLinkedParentJID\x18\x01 \x02(\x0b\x32\x0c.neonize.JID\".\n\x11GroupIsDefaultSub\x12\x19\n\x11IsDefaultSubGroup\x18\x01 \x02(\x08\">\n\x1aGroupParticipantAddRequest\x12\x0c\n\x04\x43ode\x18\x01 \x02(\t\x12\x12\n\nExpiration\x18\x02 \x02(\x02\"\xcc\x01\n\x10GroupParticipant\x12\x19\n\x03JID\x18\x01 \x01(\x0b\x32\x0c.neonize.JID\x12\x19\n\x03LID\x18\x02 \x02(\x0b\x32\x0c.neonize.JID\x12\x0f\n\x07IsAdmin\x18\x03 \x02(\x08\x12\x14\n\x0cIsSuperAdmin\x18\x04 \x02(\x08\x12\x13\n\x0b\x44isplayName\x18\x05 \x02(\t\x12\r\n\x05\x45rror\x18\x06 \x02(\x05\x12\x37\n\nAddRequest\x18\x07 \x01(\x0b\x32#.neonize.GroupParticipantAddRequest\"\x83\x05\n\tGroupInfo\x12\x1e\n\x08OwnerJID\x18\x02 \x02(\x0b\x32\x0c.neonize.JID\x12\x19\n\x03JID\x18\x01 \x02(\x0b\x32\x0c.neonize.JID\x12%\n\tGroupName\x18\x03 \x02(\x0b\x32\x12.neonize.GroupName\x12\'\n\nGroupTopic\x18\x04 \x02(\x0b\x32\x13.neonize.GroupTopic\x12)\n\x0bGroupLocked\x18\x05 \x02(\x0b\x32\x14.neonize.GroupLocked\x12-\n\rGroupAnnounce\x18\x06 \x02(\x0b\x32\x16.neonize.GroupAnnounce\x12/\n\x0eGroupEphemeral\x18\x07 \x02(\x0b\x32\x17.neonize.GroupEphemeral\x12/\n\x0eGroupIncognito\x18\x08 \x02(\x0b\x32\x17.neonize.GroupIncognito\x12)\n\x0bGroupParent\x18\t \x02(\x0b\x32\x14.neonize.GroupParent\x12\x35\n\x11GroupLinkedParent\x18\n \x02(\x0b\x32\x1a.neonize.GroupLinkedParent\x12\x35\n\x11GroupIsDefaultSub\x18\x0b \x02(\x0b\x32\x1a.neonize.GroupIsDefaultSub\x12\x14\n\x0cGroupCreated\x18\x0c \x02(\x02\x12\x1c\n\x14ParticipantVersionID\x18\r \x02(\t\x12/\n\x0cParticipants\x18\x0e \x03(\x0b\x32\x19.neonize.GroupParticipant\"1\n\x12GroupMemberAddMode\x12\x1b\n\x17GroupMemberAddModeAdmin\x10\x01\"\xb8\x01\n\x13MessageDebugTimings\x12\r\n\x05Queue\x18\x01 \x02(\x03\x12\x0f\n\x07Marshal\x18\x02 \x02(\x03\x12\x17\n\x0fGetParticipants\x18\x03 \x02(\x03\x12\x12\n\nGetDevices\x18\x04 \x02(\x03\x12\x14\n\x0cGroupEncrypt\x18\x05 \x02(\x03\x12\x13\n\x0bPeerEncrypt\x18\x06 \x02(\x03\x12\x0c\n\x04Send\x18\x07 \x02(\x03\x12\x0c\n\x04Resp\x18\x08 \x02(\x03\x12\r\n\x05Retry\x18\t \x02(\x03\"s\n\x0cSendResponse\x12\x11\n\tTimestamp\x18\x01 \x02(\x03\x12\n\n\x02ID\x18\x02 \x02(\t\x12\x10\n\x08ServerID\x18\x03 \x02(\x03\x12\x32\n\x0c\x44\x65\x62ugTimings\x18\x04 \x02(\x0b\x32\x1c.neonize.MessageDebugTimings\"W\n\x19SendMessageReturnFunction\x12\r\n\x05\x45rror\x18\x01 \x01(\t\x12+\n\x0cSendResponse\x18\x02 \x01(\x0b\x32\x15.neonize.SendResponse\"R\n\x1aGetGroupInfoReturnFunction\x12%\n\tGroupInfo\x18\x01 \x01(\x0b\x32\x12.neonize.GroupInfo\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"K\n\x1fJoinGroupWithLinkReturnFunction\x12\r\n\x05\x45rror\x18\x01 \x01(\t\x12\x19\n\x03Jid\x18\x02 \x01(\x0b\x32\x0c.neonize.JID\"E\n GetGroupInviteLinkReturnFunction\x12\x12\n\nInviteLink\x18\x01 \x01(\t\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"7\n\x16\x44ownloadReturnFunction\x12\x0e\n\x06\x42inary\x18\x01 \x01(\x0c\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"V\n\x14UploadReturnFunction\x12/\n\x0eUploadResponse\x18\x01 \x01(\x0b\x32\x17.neonize.UploadResponse\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"?\n\x1bSetGroupPhotoReturnFunction\x12\x11\n\tPictureID\x18\x01 \x02(\t\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"h\n\x1aIsOnWhatsAppReturnFunction\x12;\n\x14IsOnWhatsAppResponse\x18\x01 \x03(\x0b\x32\x1d.neonize.IsOnWhatsAppResponse\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"a\n\x1fGetUserInfoSingleReturnFunction\x12\x19\n\x03JID\x18\x01 \x01(\x0b\x32\x0c.neonize.JID\x12#\n\x08UserInfo\x18\x02 \x01(\x0b\x32\x11.neonize.UserInfo\"g\n\x19GetUserInfoReturnFunction\x12;\n\tUsersInfo\x18\x01 \x03(\x0b\x32(.neonize.GetUserInfoSingleReturnFunction\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"Z\n\x1b\x42uildPollVoteReturnFunction\x12,\n\x08PollVote\x18\x01 \x01(\x0b\x32\x1a.WAWebProtobufsE2E.Message\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"h\n\x1e\x43reateNewsLetterReturnFunction\x12\x37\n\x12NewsletterMetadata\x18\x01 \x01(\x0b\x32\x1b.neonize.NewsletterMetadata\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"R\n\x1aGetBlocklistReturnFunction\x12%\n\tBlocklist\x18\x01 \x01(\x0b\x32\x12.neonize.Blocklist\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"=\n\x1eGetContactQRLinkReturnFunction\x12\x0c\n\x04Link\x18\x01 \x02(\t\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"L\n\x17GroupParticipantRequest\x12!\n\x0bParticipant\x18\x01 \x01(\x0b\x32\x0c.neonize.JID\x12\x0e\n\x06TimeAt\x18\x02 \x01(\x04\"r\n)GetGroupRequestParticipantsReturnFunction\x12\x36\n\x0cParticipants\x18\x01 \x03(\x0b\x32 .neonize.GroupParticipantRequest\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"Q\n\x1dGetJoinedGroupsReturnFunction\x12!\n\x05Group\x18\x01 \x03(\x0b\x32\x12.neonize.GroupInfo\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"\xb7\x01\n\x0eReqCreateGroup\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\"\n\x0cParticipants\x18\x02 \x03(\x0b\x32\x0c.neonize.JID\x12\x11\n\tCreateKey\x18\x03 \x02(\t\x12)\n\x0bGroupParent\x18\x04 \x01(\x0b\x32\x14.neonize.GroupParent\x12\x35\n\x11GroupLinkedParent\x18\x05 \x01(\x0b\x32\x1a.neonize.GroupLinkedParent\"&\n\x08JIDArray\x12\x1a\n\x04JIDS\x18\x01 \x03(\x0b\x32\x0c.neonize.JID\"\x1b\n\x0b\x41rrayString\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\t\";\n\x15NewsLetterMessageMeta\x12\x0e\n\x06\x45\x64itTS\x18\x01 \x02(\x03\x12\x12\n\nOriginalTS\x18\x02 \x02(\x03\"5\n\x0bGroupDelete\x12\x0f\n\x07\x44\x65leted\x18\x01 \x02(\x08\x12\x15\n\rDeletedReason\x18\x02 \x02(\t\"\xcc\x03\n\x07Message\x12\"\n\x04Info\x18\x01 \x02(\x0b\x32\x14.neonize.MessageInfo\x12+\n\x07Message\x18\x02 \x01(\x0b\x32\x1a.WAWebProtobufsE2E.Message\x12\x13\n\x0bIsEphemeral\x18\x03 \x02(\x08\x12\x12\n\nIsViewOnce\x18\x04 \x02(\x08\x12\x14\n\x0cIsViewOnceV2\x18\x05 \x02(\x08\x12\x1d\n\x15IsViewOnceV2Extension\x18\x06 \x02(\x08\x12\x1d\n\x15IsDocumentWithCaption\x18\x07 \x02(\x08\x12\x17\n\x0fIsLottieSticker\x18\x08 \x02(\x08\x12\x0e\n\x06IsEdit\x18\t \x02(\x08\x12\x37\n\x0cSourceWebMsg\x18\n \x01(\x0b\x32!.WAWebProtobufsWeb.WebMessageInfo\x12\x1c\n\x14UnavailableRequestID\x18\x0b \x02(\t\x12\x12\n\nRetryCount\x18\x0c \x02(\x03\x12\x36\n\x0eNewsLetterMeta\x18\r \x01(\x0b\x32\x1e.neonize.NewsLetterMessageMeta\x12\'\n\x03Raw\x18\x0e \x01(\x0b\x32\x1a.WAWebProtobufsE2E.Message\"L\n\x16\x43reateNewsletterParams\x12\x0c\n\x04Name\x18\x01 \x02(\t\x12\x13\n\x0b\x44\x65scription\x18\x02 \x02(\t\x12\x0f\n\x07Picture\x18\x03 \x02(\x0c\"\x97\x01\n\x16WrappedNewsletterState\x12=\n\x04Type\x18\x01 \x02(\x0e\x32/.neonize.WrappedNewsletterState.NewsletterState\">\n\x0fNewsletterState\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\r\n\tSUSPENDED\x10\x02\x12\x10\n\x0cGEOSUSPENDED\x10\x03\">\n\x0eNewsletterText\x12\x0c\n\x04Text\x18\x01 \x02(\t\x12\n\n\x02ID\x18\x02 \x02(\t\x12\x12\n\nUpdateTime\x18\x03 \x02(\x03\"O\n\x12ProfilePictureInfo\x12\x0b\n\x03URL\x18\x01 \x02(\t\x12\n\n\x02ID\x18\x02 \x02(\t\x12\x0c\n\x04Type\x18\x03 \x02(\t\x12\x12\n\nDirectPath\x18\x04 \x02(\t\"\xb0\x01\n\x1aNewsletterReactionSettings\x12J\n\x05Value\x18\x01 \x02(\x0e\x32;.neonize.NewsletterReactionSettings.NewsletterReactionsMode\"F\n\x17NewsletterReactionsMode\x12\x07\n\x03\x41LL\x10\x01\x12\t\n\x05\x42\x41SIC\x10\x02\x12\x08\n\x04NONE\x10\x03\x12\r\n\tBLOCKLIST\x10\x04\"O\n\x11NewsletterSetting\x12:\n\rReactionCodes\x18\x01 \x02(\x0b\x32#.neonize.NewsletterReactionSettings\"\xd3\x03\n\x18NewsletterThreadMetadata\x12\x14\n\x0c\x43reationTime\x18\x01 \x02(\x03\x12\x12\n\nInviteCode\x18\x02 \x02(\t\x12%\n\x04Name\x18\x03 \x02(\x0b\x32\x17.neonize.NewsletterText\x12,\n\x0b\x44\x65scription\x18\x04 \x02(\x0b\x32\x17.neonize.NewsletterText\x12\x17\n\x0fSubscriberCount\x18\x05 \x02(\x03\x12X\n\x11VerificationState\x18\x06 \x02(\x0e\x32=.neonize.NewsletterThreadMetadata.NewsletterVerificationState\x12,\n\x07Picture\x18\x07 \x01(\x0b\x32\x1b.neonize.ProfilePictureInfo\x12,\n\x07Preview\x18\x08 \x02(\x0b\x32\x1b.neonize.ProfilePictureInfo\x12,\n\x08Settings\x18\t \x02(\x0b\x32\x1a.neonize.NewsletterSetting\";\n\x1bNewsletterVerificationState\x12\x0c\n\x08VERIFIED\x10\x01\x12\x0e\n\nUNVERIFIED\x10\x02\"m\n\x18NewsletterViewerMetadata\x12*\n\x04Mute\x18\x01 \x02(\x0e\x32\x1c.neonize.NewsletterMuteState\x12%\n\x04Role\x18\x02 \x02(\x0e\x32\x17.neonize.NewsletterRole\"\xcc\x01\n\x12NewsletterMetadata\x12\x18\n\x02ID\x18\x01 \x02(\x0b\x32\x0c.neonize.JID\x12.\n\x05State\x18\x02 \x02(\x0b\x32\x1f.neonize.WrappedNewsletterState\x12\x35\n\nThreadMeta\x18\x03 \x02(\x0b\x32!.neonize.NewsletterThreadMetadata\x12\x35\n\nViewerMeta\x18\x04 \x01(\x0b\x32!.neonize.NewsletterViewerMetadata\"6\n\tBlocklist\x12\r\n\x05\x44Hash\x18\x01 \x02(\t\x12\x1a\n\x04JIDs\x18\x02 \x03(\x0b\x32\x0c.neonize.JID\"\'\n\x08Reaction\x12\x0c\n\x04type\x18\x01 \x02(\t\x12\r\n\x05\x63ount\x18\x02 \x02(\x03\"\x98\x01\n\x11NewsletterMessage\x12\x17\n\x0fMessageServerID\x18\x01 \x02(\x03\x12\x12\n\nViewsCount\x18\x02 \x02(\x03\x12)\n\x0eReactionCounts\x18\x03 \x03(\x0b\x32\x11.neonize.Reaction\x12+\n\x07Message\x18\x04 \x02(\x0b\x32\x1a.WAWebProtobufsE2E.Message\"p\n(GetNewsletterMessageUpdateReturnFunction\x12\x35\n\x11NewsletterMessage\x18\x01 \x03(\x0b\x32\x1a.neonize.NewsletterMessage\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"\xa5\x04\n\x0fPrivacySettings\x12\x39\n\x08GroupAdd\x18\x01 \x02(\x0e\x32\'.neonize.PrivacySettings.PrivacySetting\x12\x39\n\x08LastSeen\x18\x02 \x02(\x0e\x32\'.neonize.PrivacySettings.PrivacySetting\x12\x37\n\x06Status\x18\x03 \x02(\x0e\x32\'.neonize.PrivacySettings.PrivacySetting\x12\x38\n\x07Profile\x18\x04 \x02(\x0e\x32\'.neonize.PrivacySettings.PrivacySetting\x12=\n\x0cReadReceipts\x18\x05 \x02(\x0e\x32\'.neonize.PrivacySettings.PrivacySetting\x12\x38\n\x07\x43\x61llAdd\x18\x06 \x02(\x0e\x32\'.neonize.PrivacySettings.PrivacySetting\x12\x37\n\x06Online\x18\x07 \x02(\x0e\x32\'.neonize.PrivacySettings.PrivacySetting\"w\n\x0ePrivacySetting\x12\r\n\tUNDEFINED\x10\x01\x12\x07\n\x03\x41LL\x10\x02\x12\x0c\n\x08\x43ONTACTS\x10\x03\x12\x15\n\x11\x43ONTACT_BLACKLIST\x10\x04\x12\x13\n\x0fMATCH_LAST_SEEN\x10\x05\x12\t\n\x05KNOWN\x10\x06\x12\x08\n\x04NONE\x10\x07\"u\n\tNodeAttrs\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x11\n\x07\x62oolean\x18\x02 \x01(\x08H\x00\x12\x11\n\x07integer\x18\x03 \x01(\x03H\x00\x12\x0e\n\x04text\x18\x04 \x01(\tH\x00\x12\x1b\n\x03jid\x18\x05 \x01(\x0b\x32\x0c.neonize.JIDH\x00\x42\x07\n\x05Value\"w\n\x04Node\x12\x0b\n\x03Tag\x18\x01 \x02(\t\x12!\n\x05\x41ttrs\x18\x02 \x03(\x0b\x32\x12.neonize.NodeAttrs\x12\x1c\n\x05Nodes\x18\x03 \x03(\x0b\x32\r.neonize.Node\x12\x12\n\x03Nil\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\r\n\x05\x42ytes\x18\x05 \x01(\x0c\"X\n\tInfoQuery\x12\x11\n\tNamespace\x18\x01 \x02(\t\x12\x0c\n\x04Type\x18\x02 \x02(\t\x12\n\n\x02To\x18\x03 \x02(\t\x12\x1e\n\x07\x43ontent\x18\x04 \x03(\x0b\x32\r.neonize.Node\"S\n\x17GetProfilePictureParams\x12\x0f\n\x07Preview\x18\x01 \x01(\x08\x12\x12\n\nExistingID\x18\x02 \x01(\t\x12\x13\n\x0bIsCommunity\x18\x03 \x01(\x08\"^\n\x1fGetProfilePictureReturnFunction\x12,\n\x07Picture\x18\x01 \x01(\x0b\x32\x1b.neonize.ProfilePictureInfo\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"\xb7\x01\n\rStatusPrivacy\x12\x36\n\x04Type\x18\x01 \x02(\x0e\x32(.neonize.StatusPrivacy.StatusPrivacyType\x12\x1a\n\x04List\x18\x02 \x03(\x0b\x32\x0c.neonize.JID\x12\x11\n\tIsDefault\x18\x03 \x02(\x08\"?\n\x11StatusPrivacyType\x12\x0c\n\x08\x43ONTACTS\x10\x01\x12\r\n\tBLACKLIST\x10\x02\x12\r\n\tWHITELIST\x10\x03\"^\n\x1eGetStatusPrivacyReturnFunction\x12-\n\rStatusPrivacy\x18\x01 \x03(\x0b\x32\x16.neonize.StatusPrivacy\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"\x8a\x01\n\x0fGroupLinkTarget\x12\x19\n\x03JID\x18\x01 \x02(\x0b\x32\x0c.neonize.JID\x12%\n\tGroupName\x18\x02 \x02(\x0b\x32\x12.neonize.GroupName\x12\x35\n\x11GroupIsDefaultSub\x18\x03 \x02(\x0b\x32\x1a.neonize.GroupIsDefaultSub\"\xb3\x01\n\x0fGroupLinkChange\x12\x31\n\x04Type\x18\x01 \x02(\x0e\x32#.neonize.GroupLinkChange.ChangeType\x12\x14\n\x0cUnlinkReason\x18\x02 \x02(\t\x12\'\n\x05Group\x18\x03 \x02(\x0b\x32\x18.neonize.GroupLinkTarget\".\n\nChangeType\x12\n\n\x06PARENT\x10\x01\x12\x07\n\x03SUB\x10\x02\x12\x0b\n\x07SIBLING\x10\x03\"^\n\x1aGetSubGroupsReturnFunction\x12\x31\n\x0fGroupLinkTarget\x18\x01 \x03(\x0b\x32\x18.neonize.GroupLinkTarget\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"h\n&GetSubscribedNewslettersReturnFunction\x12/\n\nNewsletter\x18\x01 \x03(\x0b\x32\x1b.neonize.NewsletterMetadata\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"H\n\x1cGetUserDevicesreturnFunction\x12\x19\n\x03JID\x18\x01 \x03(\x0b\x32\x0c.neonize.JID\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"O\n,NewsletterSubscribeLiveUpdatesReturnFunction\x12\x10\n\x08\x44uration\x18\x01 \x01(\x03\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"m\n\x0fPairPhoneParams\x12\r\n\x05phone\x18\x01 \x01(\t\x12\x1c\n\x14showPushNotification\x18\x02 \x01(\x08\x12\x12\n\nclientType\x18\x03 \x01(\x05\x12\x19\n\x11\x63lientDisplayName\x18\x04 \x01(\t\"P\n\x13\x43ontactQRLinkTarget\x12\x19\n\x03JID\x18\x01 \x02(\x0b\x32\x0c.neonize.JID\x12\x0c\n\x04Type\x18\x02 \x02(\t\x12\x10\n\x08PushName\x18\x03 \x02(\t\"h\n\"ResolveContactQRLinkReturnFunction\x12\x33\n\rContactQrLink\x18\x01 \x01(\x0b\x32\x1c.neonize.ContactQRLinkTarget\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"\x98\x01\n\x19\x42usinessMessageLinkTarget\x12\x19\n\x03JID\x18\x01 \x02(\x0b\x32\x0c.neonize.JID\x12\x10\n\x08PushName\x18\x02 \x02(\t\x12\x14\n\x0cVerifiedName\x18\x03 \x02(\t\x12\x10\n\x08IsSigned\x18\x04 \x02(\x08\x12\x15\n\rVerifiedLevel\x18\x05 \x02(\t\x12\x0f\n\x07Message\x18\x06 \x02(\t\"x\n(ResolveBusinessMessageLinkReturnFunction\x12=\n\x11MessageLinkTarget\x18\x01 \x01(\x0b\x32\".neonize.BusinessMessageLinkTarget\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"\\\n\x0cMutationInfo\x12\r\n\x05Index\x18\x01 \x03(\t\x12\x0f\n\x07Version\x18\x02 \x02(\x05\x12,\n\x05Value\x18\x03 \x02(\x0b\x32\x1d.WASyncAction.SyncActionValue\"\xe3\x01\n\tPatchInfo\x12\x11\n\tTimestamp\x18\x01 \x02(\x03\x12,\n\x04Type\x18\x02 \x02(\x0e\x32\x1e.neonize.PatchInfo.WAPatchName\x12(\n\tMutations\x18\x03 \x03(\x0b\x32\x15.neonize.MutationInfo\"k\n\x0bWAPatchName\x12\x12\n\x0e\x43RITICAL_BLOCK\x10\x01\x12\x18\n\x14\x43RITICAL_UNBLOCK_LOW\x10\x02\x12\x0f\n\x0bREGULAR_LOW\x10\x03\x12\x10\n\x0cREGULAR_HIGH\x10\x04\x12\x0b\n\x07REGULAR\x10\x05\"X\n!ContactsPutPushNameReturnFunction\x12\x0e\n\x06Status\x18\x01 \x02(\x08\x12\x14\n\x0cPreviousName\x18\x02 \x01(\t\x12\r\n\x05\x45rror\x18\x03 \x01(\t\"N\n\x0c\x43ontactEntry\x12\x19\n\x03JID\x18\x01 \x02(\x0b\x32\x0c.neonize.JID\x12\x11\n\tFirstName\x18\x02 \x02(\t\x12\x10\n\x08\x46ullName\x18\x03 \x02(\t\"@\n\x11\x43ontactEntryArray\x12+\n\x0c\x43ontactEntry\x18\x01 \x03(\x0b\x32\x15.neonize.ContactEntry\"\\\n\x1fSetPrivacySettingReturnFunction\x12*\n\x08settings\x18\x01 \x01(\x0b\x32\x18.neonize.PrivacySettings\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"\\\n ContactsGetContactReturnFunction\x12)\n\x0b\x43ontactInfo\x18\x01 \x01(\x0b\x32\x14.neonize.ContactInfo\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"i\n\x0b\x43ontactInfo\x12\r\n\x05\x46ound\x18\x01 \x02(\x08\x12\x11\n\tFirstName\x18\x02 \x02(\t\x12\x10\n\x08\x46ullName\x18\x03 \x02(\t\x12\x10\n\x08PushName\x18\x04 \x02(\t\x12\x14\n\x0c\x42usinessName\x18\x05 \x02(\t\"H\n\x07\x43ontact\x12\x19\n\x03JID\x18\x01 \x02(\x0b\x32\x0c.neonize.JID\x12\"\n\x04Info\x18\x02 \x02(\x0b\x32\x14.neonize.ContactInfo\"X\n$ContactsGetAllContactsReturnFunction\x12!\n\x07\x43ontact\x18\x01 \x03(\x0b\x32\x10.neonize.Contact\x12\r\n\x05\x45rror\x18\x02 \x01(\t\"\x13\n\x02QR\x12\r\n\x05\x43odes\x18\x01 \x03(\t\"\xad\x01\n\nPairStatus\x12\x18\n\x02ID\x18\x01 \x02(\x0b\x32\x0c.neonize.JID\x12\x14\n\x0c\x42usinessName\x18\x02 \x02(\t\x12\x10\n\x08Platform\x18\x03 \x02(\t\x12+\n\x06Status\x18\x04 \x02(\x0e\x32\x1b.neonize.PairStatus.PStatus\x12\r\n\x05\x45rror\x18\x05 \x01(\t\"!\n\x07PStatus\x12\t\n\x05\x45RROR\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\"\x1b\n\tConnected\x12\x0e\n\x06status\x18\x01 \x02(\x08\";\n\x10KeepAliveTimeout\x12\x12\n\nErrorCount\x18\x01 \x02(\x03\x12\x13\n\x0bLastSuccess\x18\x02 \x02(\x03\"\x13\n\x11KeepAliveRestored\"M\n\tLoggedOut\x12\x11\n\tOnConnect\x18\x01 \x02(\x08\x12-\n\x06Reason\x18\x02 \x02(\x0e\x32\x1d.neonize.ConnectFailureReason\"\x10\n\x0eStreamReplaced\"\xe7\x01\n\x0cTemporaryBan\x12\x31\n\x04\x43ode\x18\x01 \x02(\x0e\x32#.neonize.TemporaryBan.TempBanReason\x12\x0e\n\x06\x45xpire\x18\x02 \x02(\x03\"\x93\x01\n\rTempBanReason\x12\x1b\n\x17SEND_TO_TOO_MANY_PEOPLE\x10\x01\x12\x14\n\x10\x42LOCKED_BY_USERS\x10\x02\x12\x1b\n\x17\x43REATED_TOO_MANY_GROUPS\x10\x03\x12\x1e\n\x1aSENT_TOO_MANY_SAME_MESSAGE\x10\x04\x12\x12\n\x0e\x42ROADCAST_LIST\x10\x05\"l\n\x0e\x43onnectFailure\x12-\n\x06Reason\x18\x01 \x02(\x0e\x32\x1d.neonize.ConnectFailureReason\x12\x0f\n\x07Message\x18\x02 \x02(\t\x12\x1a\n\x03Raw\x18\x03 \x02(\x0b\x32\r.neonize.Node\"\x10\n\x0e\x43lientOutdated\"7\n\x0bStreamError\x12\x0c\n\x04\x43ode\x18\x01 \x02(\t\x12\x1a\n\x03Raw\x18\x04 \x02(\x0b\x32\r.neonize.Node\"\x1e\n\x0c\x44isconnected\x12\x0e\n\x06status\x18\x01 \x02(\x08\"C\n\x0bHistorySync\x12\x34\n\x04\x44\x61ta\x18\x01 \x02(\x0b\x32&.WAWebProtobufsHistorySync.HistorySync\"\xb7\x02\n\x07Receipt\x12-\n\rMessageSource\x18\x01 \x02(\x0b\x32\x16.neonize.MessageSource\x12\x12\n\nMessageIDs\x18\x02 \x03(\t\x12\x11\n\tTimestamp\x18\x03 \x02(\x03\x12*\n\x04Type\x18\x04 \x02(\x0e\x32\x1c.neonize.Receipt.ReceiptType\"\xa9\x01\n\x0bReceiptType\x12\r\n\tDELIVERED\x10\x01\x12\n\n\x06SENDER\x10\x02\x12\t\n\x05RETRY\x10\x03\x12\x08\n\x04READ\x10\x04\x12\r\n\tREAD_SELF\x10\x05\x12\n\n\x06PLAYED\x10\x06\x12\x0f\n\x0bPLAYED_SELF\x10\x07\x12\x10\n\x0cSERVER_ERROR\x10\x08\x12\x0c\n\x08INACTIVE\x10\t\x12\x0c\n\x08PEER_MSG\x10\n\x12\x10\n\x0cHISTORY_SYNC\x10\x0b\"\xfd\x01\n\x0c\x43hatPresence\x12-\n\rMessageSource\x18\x01 \x02(\x0b\x32\x16.neonize.MessageSource\x12\x31\n\x05State\x18\x02 \x02(\x0e\x32\".neonize.ChatPresence.ChatPresence\x12\x36\n\x05Media\x18\x03 \x02(\x0e\x32\'.neonize.ChatPresence.ChatPresenceMedia\")\n\x0c\x43hatPresence\x12\r\n\tCOMPOSING\x10\x01\x12\n\n\x06PAUSED\x10\x02\"(\n\x11\x43hatPresenceMedia\x12\x08\n\x04TEXT\x10\x01\x12\t\n\x05\x41UDIO\x10\x02\"M\n\x08Presence\x12\x1a\n\x04\x46rom\x18\x01 \x02(\x0b\x32\x0c.neonize.JID\x12\x13\n\x0bUnavailable\x18\x02 \x02(\x08\x12\x10\n\x08LastSeen\x18\x03 \x02(\x03\"e\n\x0bJoinedGroup\x12\x0e\n\x06Reason\x18\x01 \x02(\t\x12\x0c\n\x04Type\x18\x02 \x02(\t\x12\x11\n\tCreateKey\x18\x03 \x02(\t\x12%\n\tGroupInfo\x18\x04 \x02(\x0b\x32\x12.neonize.GroupInfo\"\xaf\x05\n\x0eGroupInfoEvent\x12\x19\n\x03JID\x18\x01 \x02(\x0b\x32\x0c.neonize.JID\x12\x0e\n\x06Notify\x18\x02 \x02(\t\x12\x1c\n\x06Sender\x18\x03 \x01(\x0b\x32\x0c.neonize.JID\x12\x11\n\tTimestamp\x18\x04 \x02(\x03\x12 \n\x04Name\x18\x05 \x01(\x0b\x32\x12.neonize.GroupName\x12\"\n\x05Topic\x18\x06 \x01(\x0b\x32\x13.neonize.GroupTopic\x12$\n\x06Locked\x18\x07 \x01(\x0b\x32\x14.neonize.GroupLocked\x12(\n\x08\x41nnounce\x18\x08 \x01(\x0b\x32\x16.neonize.GroupAnnounce\x12*\n\tEphemeral\x18\t \x01(\x0b\x32\x17.neonize.GroupEphemeral\x12$\n\x06\x44\x65lete\x18\n \x01(\x0b\x32\x14.neonize.GroupDelete\x12&\n\x04Link\x18\x0b \x01(\x0b\x32\x18.neonize.GroupLinkChange\x12(\n\x06Unlink\x18\x0c \x01(\x0b\x32\x18.neonize.GroupLinkChange\x12\x15\n\rNewInviteLink\x18\r \x01(\t\x12!\n\x19PrevParticipantsVersionID\x18\x0e \x02(\t\x12\x1c\n\x14ParticipantVersionID\x18\x0f \x02(\t\x12\x12\n\nJoinReason\x18\x10 \x02(\t\x12\x1a\n\x04Join\x18\x11 \x03(\x0b\x32\x0c.neonize.JID\x12\x1b\n\x05Leave\x18\x12 \x03(\x0b\x32\x0c.neonize.JID\x12\x1d\n\x07Promote\x18\x13 \x03(\x0b\x32\x0c.neonize.JID\x12\x1c\n\x06\x44\x65mote\x18\x14 \x03(\x0b\x32\x0c.neonize.JID\x12%\n\x0eUnknownChanges\x18\x15 \x03(\x0b\x32\r.neonize.Node\"e\n\x07Picture\x12\x19\n\x03JID\x18\x01 \x02(\x0b\x32\x0c.neonize.JID\x12\x1c\n\x06\x41uthor\x18\x02 \x02(\x0b\x32\x0c.neonize.JID\x12\x11\n\tTimestamp\x18\x03 \x02(\x03\x12\x0e\n\x06Remove\x18\x04 \x02(\x08\"P\n\x0eIdentityChange\x12\x19\n\x03JID\x18\x01 \x02(\x0b\x32\x0c.neonize.JID\x12\x11\n\tTimestamp\x18\x02 \x02(\x03\x12\x10\n\x08Implicit\x18\x03 \x02(\x08\"\xf2\x01\n\x14privacySettingsEvent\x12-\n\x0bNewSettings\x18\x01 \x02(\x0b\x32\x18.neonize.PrivacySettings\x12\x17\n\x0fGroupAddChanged\x18\x02 \x02(\x08\x12\x17\n\x0fLastSeenChanged\x18\x03 \x02(\x08\x12\x15\n\rStatusChanged\x18\x04 \x02(\x08\x12\x16\n\x0eProfileChanged\x18\x05 \x02(\x08\x12\x1b\n\x13ReadReceiptsChanged\x18\x06 \x02(\x08\x12\x15\n\rOnlineChanged\x18\x07 \x02(\x08\x12\x16\n\x0e\x43\x61llAddChanged\x18\x08 \x02(\x08\"u\n\x12OfflineSyncPreview\x12\r\n\x05Total\x18\x01 \x02(\x05\x12\x16\n\x0e\x41ppDataChanges\x18\x02 \x02(\x05\x12\x0f\n\x07Message\x18\x03 \x02(\x05\x12\x15\n\rNotifications\x18\x04 \x02(\x05\x12\x10\n\x08Receipts\x18\x05 \x02(\x05\"%\n\x14OfflineSyncCompleted\x12\r\n\x05\x43ount\x18\x01 \x02(\x05\"\xb2\x01\n\x0e\x42locklistEvent\x12/\n\x06\x41\x63tion\x18\x01 \x02(\x0e\x32\x1f.neonize.BlocklistEvent.Actions\x12\r\n\x05\x44HASH\x18\x02 \x02(\t\x12\x11\n\tPrevDHash\x18\x03 \x02(\t\x12)\n\x07\x43hanges\x18\x04 \x03(\x0b\x32\x18.neonize.BlocklistChange\"\"\n\x07\x41\x63tions\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x01\x12\n\n\x06MODIFY\x10\x02\"\x84\x01\n\x0f\x42locklistChange\x12\x19\n\x03JID\x18\x01 \x02(\x0b\x32\x0c.neonize.JID\x12\x34\n\x0b\x42lockAction\x18\x02 \x02(\x0e\x32\x1f.neonize.BlocklistChange.Action\" \n\x06\x41\x63tion\x12\t\n\x05\x42LOCK\x10\x01\x12\x0b\n\x07UNBLOCK\x10\x02\"I\n\x0eNewsletterJoin\x12\x37\n\x12NewsletterMetadata\x18\x01 \x02(\x0b\x32\x1b.neonize.NewsletterMetadata\"R\n\x0fNewsletterLeave\x12\x18\n\x02ID\x18\x01 \x02(\x0b\x32\x0c.neonize.JID\x12%\n\x04Role\x18\x02 \x02(\x0e\x32\x17.neonize.NewsletterRole\"\\\n\x14NewsletterMuteChange\x12\x18\n\x02ID\x18\x01 \x02(\x0b\x32\x0c.neonize.JID\x12*\n\x04Mute\x18\x02 \x02(\x0e\x32\x1c.neonize.NewsletterMuteState\"m\n\x14NewsletterLiveUpdate\x12\x19\n\x03JID\x18\x01 \x02(\x0b\x32\x0c.neonize.JID\x12\x0c\n\x04TIME\x18\x02 \x02(\x03\x12,\n\x08Messages\x18\x03 \x03(\x0b\x32\x1a.neonize.NewsletterMessage\"q\n\rBasicCallMeta\x12\x1a\n\x04\x66rom\x18\x01 \x02(\x0b\x32\x0c.neonize.JID\x12\x11\n\ttimestamp\x18\x02 \x02(\x03\x12!\n\x0b\x63\x61llCreator\x18\x03 \x02(\x0b\x32\x0c.neonize.JID\x12\x0e\n\x06\x63\x61llID\x18\x04 \x02(\t\"?\n\x0e\x43\x61llRemoteMeta\x12\x16\n\x0eremotePlatform\x18\x01 \x02(\t\x12\x15\n\rremoteVersion\x18\x02 \x02(\t\"\x88\x01\n\tCallOffer\x12-\n\rbasicCallMeta\x18\x01 \x02(\x0b\x32\x16.neonize.BasicCallMeta\x12/\n\x0e\x63\x61llRemoteMeta\x18\x02 \x02(\x0b\x32\x17.neonize.CallRemoteMeta\x12\x1b\n\x04\x64\x61ta\x18\x03 \x02(\x0b\x32\r.neonize.Node\"\x89\x01\n\nCallAccept\x12-\n\rbasicCallMeta\x18\x01 \x02(\x0b\x32\x16.neonize.BasicCallMeta\x12/\n\x0e\x63\x61llRemoteMeta\x18\x02 \x02(\x0b\x32\x17.neonize.CallRemoteMeta\x12\x1b\n\x04\x64\x61ta\x18\x03 \x02(\x0b\x32\r.neonize.Node\"\x8c\x01\n\rCallPreAccept\x12-\n\rbasicCallMeta\x18\x01 \x02(\x0b\x32\x16.neonize.BasicCallMeta\x12/\n\x0e\x63\x61llRemoteMeta\x18\x02 \x02(\x0b\x32\x17.neonize.CallRemoteMeta\x12\x1b\n\x04\x64\x61ta\x18\x03 \x02(\x0b\x32\r.neonize.Node\"\x8c\x01\n\rCallTransport\x12-\n\rbasicCallMeta\x18\x01 \x02(\x0b\x32\x16.neonize.BasicCallMeta\x12/\n\x0e\x63\x61llRemoteMeta\x18\x02 \x02(\x0b\x32\x17.neonize.CallRemoteMeta\x12\x1b\n\x04\x64\x61ta\x18\x03 \x02(\x0b\x32\r.neonize.Node\"z\n\x0f\x43\x61llOfferNotice\x12-\n\rbasicCallMeta\x18\x01 \x02(\x0b\x32\x16.neonize.BasicCallMeta\x12\r\n\x05media\x18\x02 \x02(\t\x12\x0c\n\x04type\x18\x03 \x02(\t\x12\x1b\n\x04\x64\x61ta\x18\x04 \x02(\x0b\x32\r.neonize.Node\"^\n\x10\x43\x61llRelayLatency\x12-\n\rbasicCallMeta\x18\x01 \x02(\x0b\x32\x16.neonize.BasicCallMeta\x12\x1b\n\x04\x64\x61ta\x18\x02 \x02(\x0b\x32\r.neonize.Node\"k\n\rCallTerminate\x12-\n\rbasicCallMeta\x18\x01 \x02(\x0b\x32\x16.neonize.BasicCallMeta\x12\x0e\n\x06reason\x18\x02 \x02(\t\x12\x1b\n\x04\x64\x61ta\x18\x03 \x02(\x0b\x32\r.neonize.Node\"/\n\x10UnknownCallEvent\x12\x1b\n\x04node\x18\x01 \x02(\x0b\x32\r.neonize.Node\"\xdc\x01\n\x14UndecryptableMessage\x12\"\n\x04Info\x18\x01 \x02(\x0b\x32\x14.neonize.MessageInfo\x12\x15\n\rIsUnavailable\x18\x02 \x02(\x08\x12G\n\x0f\x44\x65\x63ryptFailMode\x18\x03 \x02(\x0e\x32..neonize.UndecryptableMessage.DecryptFailModeT\"@\n\x10\x44\x65\x63ryptFailModeT\x12\x15\n\x11\x44\x45\x43RYPT_FAIL_SHOW\x10\x01\x12\x15\n\x11\x44\x45\x43RYPT_FAIL_HIDE\x10\x02\"g\n%UpdateGroupParticipantsReturnFunction\x12\r\n\x05\x45rror\x18\x01 \x01(\t\x12/\n\x0cparticipants\x18\x02 \x03(\x0b\x32\x19.neonize.GroupParticipant\"g\n GetMessageForRetryReturnFunction\x12\x16\n\x07isEmpty\x18\x01 \x01(\x08:\x05\x66\x61lse\x12+\n\x07Message\x18\x02 \x01(\x0b\x32\x1a.WAWebProtobufsE2E.Message\"X\n\x11LocalChatSettings\x12\r\n\x05\x46ound\x18\x01 \x02(\x08\x12\x12\n\nMutedUntil\x18\x02 \x02(\x01\x12\x0e\n\x06Pinned\x18\x03 \x02(\x08\x12\x10\n\x08\x41rchived\x18\x04 \x02(\x08\"\xe4\x01\n\x17ReturnFunctionWithError\x12\r\n\x05\x45rror\x18\x01 \x01(\t\x12\x37\n\x11LocalChatSettings\x18\x02 \x01(\x0b\x32\x1a.neonize.LocalChatSettingsH\x00\x12=\n\x0fPollVoteMessage\x18\x03 \x01(\x0b\x32\".WAWebProtobufsE2E.PollVoteMessageH\x00\x12\x38\n\x1bGetLinkedGroupsParticipants\x18\x04 \x01(\x0b\x32\x11.neonize.JIDArrayH\x00\x42\x08\n\x06Return\"v\n\x10SendRequestExtra\x12\n\n\x02ID\x18\x01 \x02(\t\x12\"\n\x0cInlineBotJID\x18\x02 \x02(\x0b\x32\x0c.neonize.JID\x12\x0c\n\x04Peer\x18\x03 \x02(\x08\x12\x0f\n\x07Timeout\x18\x04 \x02(\x03\x12\x13\n\x0bMediaHandle\x18\x05 \x02(\t*A\n\x0eNewsletterRole\x12\x0e\n\nSUBSCRIBER\x10\x01\x12\t\n\x05GUEST\x10\x02\x12\t\n\x05\x41\x44MIN\x10\x03\x12\t\n\x05OWNER\x10\x04*&\n\x13NewsletterMuteState\x12\x06\n\x02ON\x10\x01\x12\x07\n\x03OFF\x10\x02*\xdd\x01\n\x14\x43onnectFailureReason\x12\x0b\n\x07GENERIC\x10\x01\x12\x0e\n\nLOGGED_OUT\x10\x02\x12\x0f\n\x0bTEMP_BANNED\x10\x03\x12\x14\n\x10MAIN_DEVICE_GONE\x10\x04\x12\x12\n\x0eUNKNOWN_LOGOUT\x10\x05\x12\x13\n\x0f\x43LIENT_OUTDATED\x10\x06\x12\x12\n\x0e\x42\x41\x44_USER_AGENT\x10\x07\x12\x19\n\x15INTERNAL_SERVER_ERROR\x10\x08\x12\x10\n\x0c\x45XPERIMENTAL\x10\t\x12\x17\n\x13SERVICE_UNAVAILABLE\x10\nB\x0cZ\n./defproto')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Neonize_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\n./defproto'
  _globals['_NEWSLETTERROLE']._serialized_start=16665
  _globals['_NEWSLETTERROLE']._serialized_end=16730
  _globals['_NEWSLETTERMUTESTATE']._serialized_start=16732
  _globals['_NEWSLETTERMUTESTATE']._serialized_end=16770
  _globals['_CONNECTFAILUREREASON']._serialized_start=16773
  _globals['_CONNECTFAILUREREASON']._serialized_end=16994
  _globals['_JID']._serialized_start=211
  _globals['_JID']._serialized_end=324
  _globals['_MESSAGEINFO']._serialized_start=327
  _globals['_MESSAGEINFO']._serialized_end=632
  _globals['_UPLOADRESPONSE']._serialized_start=635
  _globals['_UPLOADRESPONSE']._serialized_end=781
  _globals['_MESSAGESOURCE']._serialized_start=784
  _globals['_MESSAGESOURCE']._serialized_end=934
  _globals['_DEVICESENTMETA']._serialized_start=936
  _globals['_DEVICESENTMETA']._serialized_end=991
  _globals['_VERIFIEDNAME']._serialized_start=994
  _globals['_VERIFIEDNAME']._serialized_end=1154
  _globals['_ISONWHATSAPPRESPONSE']._serialized_start=1156
  _globals['_ISONWHATSAPPRESPONSE']._serialized_end=1279
  _globals['_USERINFO']._serialized_start=1281
  _globals['_USERINFO']._serialized_end=1402
  _globals['_DEVICE']._serialized_start=1404
  _globals['_DEVICE']._serialized_end=1519
  _globals['_GROUPNAME']._serialized_start=1521
  _globals['_GROUPNAME']._serialized_end=1598
  _globals['_GROUPTOPIC']._serialized_start=1600
  _globals['_GROUPTOPIC']._serialized_end=1720
  _globals['_GROUPLOCKED']._serialized_start=1722
  _globals['_GROUPLOCKED']._serialized_end=1753
  _globals['_GROUPANNOUNCE']._serialized_start=1755
  _globals['_GROUPANNOUNCE']._serialized_end=1817
  _globals['_GROUPEPHEMERAL']._serialized_start=1819
  _globals['_GROUPEPHEMERAL']._serialized_end=1883
  _globals['_GROUPINCOGNITO']._serialized_start=1885
  _globals['_GROUPINCOGNITO']._serialized_end=1922
  _globals['_GROUPPARENT']._serialized_start=1924
  _globals['_GROUPPARENT']._serialized_end=1994
  _globals['_GROUPLINKEDPARENT']._serialized_start=1996
  _globals['_GROUPLINKEDPARENT']._serialized_end=2054
  _globals['_GROUPISDEFAULTSUB']._serialized_start=2056
  _globals['_GROUPISDEFAULTSUB']._serialized_end=2102
  _globals['_GROUPPARTICIPANTADDREQUEST']._serialized_start=2104
  _globals['_GROUPPARTICIPANTADDREQUEST']._serialized_end=2166
  _globals['_GROUPPARTICIPANT']._serialized_start=2169
  _globals['_GROUPPARTICIPANT']._serialized_end=2373
  _globals['_GROUPINFO']._serialized_start=2376
  _globals['_GROUPINFO']._serialized_end=3019
  _globals['_GROUPINFO_GROUPMEMBERADDMODE']._serialized_start=2970
  _globals['_GROUPINFO_GROUPMEMBERADDMODE']._serialized_end=3019
  _globals['_MESSAGEDEBUGTIMINGS']._serialized_start=3022
  _globals['_MESSAGEDEBUGTIMINGS']._serialized_end=3206
  _globals['_SENDRESPONSE']._serialized_start=3208
  _globals['_SENDRESPONSE']._serialized_end=3323
  _globals['_SENDMESSAGERETURNFUNCTION']._serialized_start=3325
  _globals['_SENDMESSAGERETURNFUNCTION']._serialized_end=3412
  _globals['_GETGROUPINFORETURNFUNCTION']._serialized_start=3414
  _globals['_GETGROUPINFORETURNFUNCTION']._serialized_end=3496
  _globals['_JOINGROUPWITHLINKRETURNFUNCTION']._serialized_start=3498
  _globals['_JOINGROUPWITHLINKRETURNFUNCTION']._serialized_end=3573
  _globals['_GETGROUPINVITELINKRETURNFUNCTION']._serialized_start=3575
  _globals['_GETGROUPINVITELINKRETURNFUNCTION']._serialized_end=3644
  _globals['_DOWNLOADRETURNFUNCTION']._serialized_start=3646
  _globals['_DOWNLOADRETURNFUNCTION']._serialized_end=3701
  _globals['_UPLOADRETURNFUNCTION']._serialized_start=3703
  _globals['_UPLOADRETURNFUNCTION']._serialized_end=3789
  _globals['_SETGROUPPHOTORETURNFUNCTION']._serialized_start=3791
  _globals['_SETGROUPPHOTORETURNFUNCTION']._serialized_end=3854
  _globals['_ISONWHATSAPPRETURNFUNCTION']._serialized_start=3856
  _globals['_ISONWHATSAPPRETURNFUNCTION']._serialized_end=3960
  _globals['_GETUSERINFOSINGLERETURNFUNCTION']._serialized_start=3962
  _globals['_GETUSERINFOSINGLERETURNFUNCTION']._serialized_end=4059
  _globals['_GETUSERINFORETURNFUNCTION']._serialized_start=4061
  _globals['_GETUSERINFORETURNFUNCTION']._serialized_end=4164
  _globals['_BUILDPOLLVOTERETURNFUNCTION']._serialized_start=4166
  _globals['_BUILDPOLLVOTERETURNFUNCTION']._serialized_end=4256
  _globals['_CREATENEWSLETTERRETURNFUNCTION']._serialized_start=4258
  _globals['_CREATENEWSLETTERRETURNFUNCTION']._serialized_end=4362
  _globals['_GETBLOCKLISTRETURNFUNCTION']._serialized_start=4364
  _globals['_GETBLOCKLISTRETURNFUNCTION']._serialized_end=4446
  _globals['_GETCONTACTQRLINKRETURNFUNCTION']._serialized_start=4448
  _globals['_GETCONTACTQRLINKRETURNFUNCTION']._serialized_end=4509
  _globals['_GROUPPARTICIPANTREQUEST']._serialized_start=4511
  _globals['_GROUPPARTICIPANTREQUEST']._serialized_end=4587
  _globals['_GETGROUPREQUESTPARTICIPANTSRETURNFUNCTION']._serialized_start=4589
  _globals['_GETGROUPREQUESTPARTICIPANTSRETURNFUNCTION']._serialized_end=4703
  _globals['_GETJOINEDGROUPSRETURNFUNCTION']._serialized_start=4705
  _globals['_GETJOINEDGROUPSRETURNFUNCTION']._serialized_end=4786
  _globals['_REQCREATEGROUP']._serialized_start=4789
  _globals['_REQCREATEGROUP']._serialized_end=4972
  _globals['_JIDARRAY']._serialized_start=4974
  _globals['_JIDARRAY']._serialized_end=5012
  _globals['_ARRAYSTRING']._serialized_start=5014
  _globals['_ARRAYSTRING']._serialized_end=5041
  _globals['_NEWSLETTERMESSAGEMETA']._serialized_start=5043
  _globals['_NEWSLETTERMESSAGEMETA']._serialized_end=5102
  _globals['_GROUPDELETE']._serialized_start=5104
  _globals['_GROUPDELETE']._serialized_end=5157
  _globals['_MESSAGE']._serialized_start=5160
  _globals['_MESSAGE']._serialized_end=5620
  _globals['_CREATENEWSLETTERPARAMS']._serialized_start=5622
  _globals['_CREATENEWSLETTERPARAMS']._serialized_end=5698
  _globals['_WRAPPEDNEWSLETTERSTATE']._serialized_start=5701
  _globals['_WRAPPEDNEWSLETTERSTATE']._serialized_end=5852
  _globals['_WRAPPEDNEWSLETTERSTATE_NEWSLETTERSTATE']._serialized_start=5790
  _globals['_WRAPPEDNEWSLETTERSTATE_NEWSLETTERSTATE']._serialized_end=5852
  _globals['_NEWSLETTERTEXT']._serialized_start=5854
  _globals['_NEWSLETTERTEXT']._serialized_end=5916
  _globals['_PROFILEPICTUREINFO']._serialized_start=5918
  _globals['_PROFILEPICTUREINFO']._serialized_end=5997
  _globals['_NEWSLETTERREACTIONSETTINGS']._serialized_start=6000
  _globals['_NEWSLETTERREACTIONSETTINGS']._serialized_end=6176
  _globals['_NEWSLETTERREACTIONSETTINGS_NEWSLETTERREACTIONSMODE']._serialized_start=6106
  _globals['_NEWSLETTERREACTIONSETTINGS_NEWSLETTERREACTIONSMODE']._serialized_end=6176
  _globals['_NEWSLETTERSETTING']._serialized_start=6178
  _globals['_NEWSLETTERSETTING']._serialized_end=6257
  _globals['_NEWSLETTERTHREADMETADATA']._serialized_start=6260
  _globals['_NEWSLETTERTHREADMETADATA']._serialized_end=6727
  _globals['_NEWSLETTERTHREADMETADATA_NEWSLETTERVERIFICATIONSTATE']._serialized_start=6668
  _globals['_NEWSLETTERTHREADMETADATA_NEWSLETTERVERIFICATIONSTATE']._serialized_end=6727
  _globals['_NEWSLETTERVIEWERMETADATA']._serialized_start=6729
  _globals['_NEWSLETTERVIEWERMETADATA']._serialized_end=6838
  _globals['_NEWSLETTERMETADATA']._serialized_start=6841
  _globals['_NEWSLETTERMETADATA']._serialized_end=7045
  _globals['_BLOCKLIST']._serialized_start=7047
  _globals['_BLOCKLIST']._serialized_end=7101
  _globals['_REACTION']._serialized_start=7103
  _globals['_REACTION']._serialized_end=7142
  _globals['_NEWSLETTERMESSAGE']._serialized_start=7145
  _globals['_NEWSLETTERMESSAGE']._serialized_end=7297
  _globals['_GETNEWSLETTERMESSAGEUPDATERETURNFUNCTION']._serialized_start=7299
  _globals['_GETNEWSLETTERMESSAGEUPDATERETURNFUNCTION']._serialized_end=7411
  _globals['_PRIVACYSETTINGS']._serialized_start=7414
  _globals['_PRIVACYSETTINGS']._serialized_end=7963
  _globals['_PRIVACYSETTINGS_PRIVACYSETTING']._serialized_start=7844
  _globals['_PRIVACYSETTINGS_PRIVACYSETTING']._serialized_end=7963
  _globals['_NODEATTRS']._serialized_start=7965
  _globals['_NODEATTRS']._serialized_end=8082
  _globals['_NODE']._serialized_start=8084
  _globals['_NODE']._serialized_end=8203
  _globals['_INFOQUERY']._serialized_start=8205
  _globals['_INFOQUERY']._serialized_end=8293
  _globals['_GETPROFILEPICTUREPARAMS']._serialized_start=8295
  _globals['_GETPROFILEPICTUREPARAMS']._serialized_end=8378
  _globals['_GETPROFILEPICTURERETURNFUNCTION']._serialized_start=8380
  _globals['_GETPROFILEPICTURERETURNFUNCTION']._serialized_end=8474
  _globals['_STATUSPRIVACY']._serialized_start=8477
  _globals['_STATUSPRIVACY']._serialized_end=8660
  _globals['_STATUSPRIVACY_STATUSPRIVACYTYPE']._serialized_start=8597
  _globals['_STATUSPRIVACY_STATUSPRIVACYTYPE']._serialized_end=8660
  _globals['_GETSTATUSPRIVACYRETURNFUNCTION']._serialized_start=8662
  _globals['_GETSTATUSPRIVACYRETURNFUNCTION']._serialized_end=8756
  _globals['_GROUPLINKTARGET']._serialized_start=8759
  _globals['_GROUPLINKTARGET']._serialized_end=8897
  _globals['_GROUPLINKCHANGE']._serialized_start=8900
  _globals['_GROUPLINKCHANGE']._serialized_end=9079
  _globals['_GROUPLINKCHANGE_CHANGETYPE']._serialized_start=9033
  _globals['_GROUPLINKCHANGE_CHANGETYPE']._serialized_end=9079
  _globals['_GETSUBGROUPSRETURNFUNCTION']._serialized_start=9081
  _globals['_GETSUBGROUPSRETURNFUNCTION']._serialized_end=9175
  _globals['_GETSUBSCRIBEDNEWSLETTERSRETURNFUNCTION']._serialized_start=9177
  _globals['_GETSUBSCRIBEDNEWSLETTERSRETURNFUNCTION']._serialized_end=9281
  _globals['_GETUSERDEVICESRETURNFUNCTION']._serialized_start=9283
  _globals['_GETUSERDEVICESRETURNFUNCTION']._serialized_end=9355
  _globals['_NEWSLETTERSUBSCRIBELIVEUPDATESRETURNFUNCTION']._serialized_start=9357
  _globals['_NEWSLETTERSUBSCRIBELIVEUPDATESRETURNFUNCTION']._serialized_end=9436
  _globals['_PAIRPHONEPARAMS']._serialized_start=9438
  _globals['_PAIRPHONEPARAMS']._serialized_end=9547
  _globals['_CONTACTQRLINKTARGET']._serialized_start=9549
  _globals['_CONTACTQRLINKTARGET']._serialized_end=9629
  _globals['_RESOLVECONTACTQRLINKRETURNFUNCTION']._serialized_start=9631
  _globals['_RESOLVECONTACTQRLINKRETURNFUNCTION']._serialized_end=9735
  _globals['_BUSINESSMESSAGELINKTARGET']._serialized_start=9738
  _globals['_BUSINESSMESSAGELINKTARGET']._serialized_end=9890
  _globals['_RESOLVEBUSINESSMESSAGELINKRETURNFUNCTION']._serialized_start=9892
  _globals['_RESOLVEBUSINESSMESSAGELINKRETURNFUNCTION']._serialized_end=10012
  _globals['_MUTATIONINFO']._serialized_start=10014
  _globals['_MUTATIONINFO']._serialized_end=10106
  _globals['_PATCHINFO']._serialized_start=10109
  _globals['_PATCHINFO']._serialized_end=10336
  _globals['_PATCHINFO_WAPATCHNAME']._serialized_start=10229
  _globals['_PATCHINFO_WAPATCHNAME']._serialized_end=10336
  _globals['_CONTACTSPUTPUSHNAMERETURNFUNCTION']._serialized_start=10338
  _globals['_CONTACTSPUTPUSHNAMERETURNFUNCTION']._serialized_end=10426
  _globals['_CONTACTENTRY']._serialized_start=10428
  _globals['_CONTACTENTRY']._serialized_end=10506
  _globals['_CONTACTENTRYARRAY']._serialized_start=10508
  _globals['_CONTACTENTRYARRAY']._serialized_end=10572
  _globals['_SETPRIVACYSETTINGRETURNFUNCTION']._serialized_start=10574
  _globals['_SETPRIVACYSETTINGRETURNFUNCTION']._serialized_end=10666
  _globals['_CONTACTSGETCONTACTRETURNFUNCTION']._serialized_start=10668
  _globals['_CONTACTSGETCONTACTRETURNFUNCTION']._serialized_end=10760
  _globals['_CONTACTINFO']._serialized_start=10762
  _globals['_CONTACTINFO']._serialized_end=10867
  _globals['_CONTACT']._serialized_start=10869
  _globals['_CONTACT']._serialized_end=10941
  _globals['_CONTACTSGETALLCONTACTSRETURNFUNCTION']._serialized_start=10943
  _globals['_CONTACTSGETALLCONTACTSRETURNFUNCTION']._serialized_end=11031
  _globals['_QR']._serialized_start=11033
  _globals['_QR']._serialized_end=11052
  _globals['_PAIRSTATUS']._serialized_start=11055
  _globals['_PAIRSTATUS']._serialized_end=11228
  _globals['_PAIRSTATUS_PSTATUS']._serialized_start=11195
  _globals['_PAIRSTATUS_PSTATUS']._serialized_end=11228
  _globals['_CONNECTED']._serialized_start=11230
  _globals['_CONNECTED']._serialized_end=11257
  _globals['_KEEPALIVETIMEOUT']._serialized_start=11259
  _globals['_KEEPALIVETIMEOUT']._serialized_end=11318
  _globals['_KEEPALIVERESTORED']._serialized_start=11320
  _globals['_KEEPALIVERESTORED']._serialized_end=11339
  _globals['_LOGGEDOUT']._serialized_start=11341
  _globals['_LOGGEDOUT']._serialized_end=11418
  _globals['_STREAMREPLACED']._serialized_start=11420
  _globals['_STREAMREPLACED']._serialized_end=11436
  _globals['_TEMPORARYBAN']._serialized_start=11439
  _globals['_TEMPORARYBAN']._serialized_end=11670
  _globals['_TEMPORARYBAN_TEMPBANREASON']._serialized_start=11523
  _globals['_TEMPORARYBAN_TEMPBANREASON']._serialized_end=11670
  _globals['_CONNECTFAILURE']._serialized_start=11672
  _globals['_CONNECTFAILURE']._serialized_end=11780
  _globals['_CLIENTOUTDATED']._serialized_start=11782
  _globals['_CLIENTOUTDATED']._serialized_end=11798
  _globals['_STREAMERROR']._serialized_start=11800
  _globals['_STREAMERROR']._serialized_end=11855
  _globals['_DISCONNECTED']._serialized_start=11857
  _globals['_DISCONNECTED']._serialized_end=11887
  _globals['_HISTORYSYNC']._serialized_start=11889
  _globals['_HISTORYSYNC']._serialized_end=11956
  _globals['_RECEIPT']._serialized_start=11959
  _globals['_RECEIPT']._serialized_end=12270
  _globals['_RECEIPT_RECEIPTTYPE']._serialized_start=12101
  _globals['_RECEIPT_RECEIPTTYPE']._serialized_end=12270
  _globals['_CHATPRESENCE']._serialized_start=12273
  _globals['_CHATPRESENCE']._serialized_end=12526
  _globals['_CHATPRESENCE_CHATPRESENCE']._serialized_start=12443
  _globals['_CHATPRESENCE_CHATPRESENCE']._serialized_end=12484
  _globals['_CHATPRESENCE_CHATPRESENCEMEDIA']._serialized_start=12486
  _globals['_CHATPRESENCE_CHATPRESENCEMEDIA']._serialized_end=12526
  _globals['_PRESENCE']._serialized_start=12528
  _globals['_PRESENCE']._serialized_end=12605
  _globals['_JOINEDGROUP']._serialized_start=12607
  _globals['_JOINEDGROUP']._serialized_end=12708
  _globals['_GROUPINFOEVENT']._serialized_start=12711
  _globals['_GROUPINFOEVENT']._serialized_end=13398
  _globals['_PICTURE']._serialized_start=13400
  _globals['_PICTURE']._serialized_end=13501
  _globals['_IDENTITYCHANGE']._serialized_start=13503
  _globals['_IDENTITYCHANGE']._serialized_end=13583
  _globals['_PRIVACYSETTINGSEVENT']._serialized_start=13586
  _globals['_PRIVACYSETTINGSEVENT']._serialized_end=13828
  _globals['_OFFLINESYNCPREVIEW']._serialized_start=13830
  _globals['_OFFLINESYNCPREVIEW']._serialized_end=13947
  _globals['_OFFLINESYNCCOMPLETED']._serialized_start=13949
  _globals['_OFFLINESYNCCOMPLETED']._serialized_end=13986
  _globals['_BLOCKLISTEVENT']._serialized_start=13989
  _globals['_BLOCKLISTEVENT']._serialized_end=14167
  _globals['_BLOCKLISTEVENT_ACTIONS']._serialized_start=14133
  _globals['_BLOCKLISTEVENT_ACTIONS']._serialized_end=14167
  _globals['_BLOCKLISTCHANGE']._serialized_start=14170
  _globals['_BLOCKLISTCHANGE']._serialized_end=14302
  _globals['_BLOCKLISTCHANGE_ACTION']._serialized_start=14270
  _globals['_BLOCKLISTCHANGE_ACTION']._serialized_end=14302
  _globals['_NEWSLETTERJOIN']._serialized_start=14304
  _globals['_NEWSLETTERJOIN']._serialized_end=14377
  _globals['_NEWSLETTERLEAVE']._serialized_start=14379
  _globals['_NEWSLETTERLEAVE']._serialized_end=14461
  _globals['_NEWSLETTERMUTECHANGE']._serialized_start=14463
  _globals['_NEWSLETTERMUTECHANGE']._serialized_end=14555
  _globals['_NEWSLETTERLIVEUPDATE']._serialized_start=14557
  _globals['_NEWSLETTERLIVEUPDATE']._serialized_end=14666
  _globals['_BASICCALLMETA']._serialized_start=14668
  _globals['_BASICCALLMETA']._serialized_end=14781
  _globals['_CALLREMOTEMETA']._serialized_start=14783
  _globals['_CALLREMOTEMETA']._serialized_end=14846
  _globals['_CALLOFFER']._serialized_start=14849
  _globals['_CALLOFFER']._serialized_end=14985
  _globals['_CALLACCEPT']._serialized_start=14988
  _globals['_CALLACCEPT']._serialized_end=15125
  _globals['_CALLPREACCEPT']._serialized_start=15128
  _globals['_CALLPREACCEPT']._serialized_end=15268
  _globals['_CALLTRANSPORT']._serialized_start=15271
  _globals['_CALLTRANSPORT']._serialized_end=15411
  _globals['_CALLOFFERNOTICE']._serialized_start=15413
  _globals['_CALLOFFERNOTICE']._serialized_end=15535
  _globals['_CALLRELAYLATENCY']._serialized_start=15537
  _globals['_CALLRELAYLATENCY']._serialized_end=15631
  _globals['_CALLTERMINATE']._serialized_start=15633
  _globals['_CALLTERMINATE']._serialized_end=15740
  _globals['_UNKNOWNCALLEVENT']._serialized_start=15742
  _globals['_UNKNOWNCALLEVENT']._serialized_end=15789
  _globals['_UNDECRYPTABLEMESSAGE']._serialized_start=15792
  _globals['_UNDECRYPTABLEMESSAGE']._serialized_end=16012
  _globals['_UNDECRYPTABLEMESSAGE_DECRYPTFAILMODET']._serialized_start=15948
  _globals['_UNDECRYPTABLEMESSAGE_DECRYPTFAILMODET']._serialized_end=16012
  _globals['_UPDATEGROUPPARTICIPANTSRETURNFUNCTION']._serialized_start=16014
  _globals['_UPDATEGROUPPARTICIPANTSRETURNFUNCTION']._serialized_end=16117
  _globals['_GETMESSAGEFORRETRYRETURNFUNCTION']._serialized_start=16119
  _globals['_GETMESSAGEFORRETRYRETURNFUNCTION']._serialized_end=16222
  _globals['_LOCALCHATSETTINGS']._serialized_start=16224
  _globals['_LOCALCHATSETTINGS']._serialized_end=16312
  _globals['_RETURNFUNCTIONWITHERROR']._serialized_start=16315
  _globals['_RETURNFUNCTIONWITHERROR']._serialized_end=16543
  _globals['_SENDREQUESTEXTRA']._serialized_start=16545
  _globals['_SENDREQUESTEXTRA']._serialized_end=16663
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waMsgTransport/WAMsgTransport.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waMsgTransport/WAMsgTransport.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waCommon import WACommon_pb2 as waCommon_dot_WACommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#waMsgTransport/WAMsgTransport.proto\x12\x0eWAMsgTransport\x1a\x17waCommon/WACommon.proto\"\xa4\r\n\x10MessageTransport\x12\x39\n\x07payload\x18\x01 \x01(\x0b\x32(.WAMsgTransport.MessageTransport.Payload\x12;\n\x08protocol\x18\x02 \x01(\x0b\x32).WAMsgTransport.MessageTransport.Protocol\x1ap\n\x07Payload\x12\x31\n\x12\x61pplicationPayload\x18\x01 \x01(\x0b\x32\x15.WACommon.SubProtocol\x12\x32\n\x0b\x66utureProof\x18\x03 \x01(\x0e\x32\x1d.WACommon.FutureProofBehavior\x1a\xa5\x0b\n\x08Protocol\x12\x44\n\x08integral\x18\x01 \x01(\x0b\x32\x32.WAMsgTransport.MessageTransport.Protocol.Integral\x12\x46\n\tancillary\x18\x02 \x01(\x0b\x32\x33.WAMsgTransport.MessageTransport.Protocol.Ancillary\x1a\xdd\x08\n\tAncillary\x12^\n\x04skdm\x18\x02 \x01(\x0b\x32P.WAMsgTransport.MessageTransport.Protocol.Ancillary.SenderKeyDistributionMessage\x12>\n\x12\x64\x65viceListMetadata\x18\x03 \x01(\x0b\x32\".WAMsgTransport.DeviceListMetadata\x12X\n\x04icdc\x18\x04 \x01(\x0b\x32J.WAMsgTransport.MessageTransport.Protocol.Ancillary.ICDCParticipantDevices\x12\\\n\x0f\x62\x61\x63kupDirective\x18\x05 \x01(\x0b\x32\x43.WAMsgTransport.MessageTransport.Protocol.Ancillary.BackupDirective\x1a\xe8\x01\n\x0f\x42\x61\x63kupDirective\x12\x11\n\tmessageID\x18\x01 \x01(\t\x12\x62\n\nactionType\x18\x02 \x01(\x0e\x32N.WAMsgTransport.MessageTransport.Protocol.Ancillary.BackupDirective.ActionType\x12\x17\n\x0fsupplementalKey\x18\x03 \x01(\t\"E\n\nActionType\x12\x08\n\x04NOOP\x10\x00\x12\n\n\x06UPSERT\x10\x01\x12\n\n\x06\x44\x45LETE\x10\x02\x12\x15\n\x11UPSERT_AND_DELETE\x10\x03\x1a\xae\x03\n\x16ICDCParticipantDevices\x12~\n\x0esenderIdentity\x18\x01 \x01(\x0b\x32\x66.WAMsgTransport.MessageTransport.Protocol.Ancillary.ICDCParticipantDevices.ICDCIdentityListDescription\x12\x83\x01\n\x13recipientIdentities\x18\x02 \x03(\x0b\x32\x66.WAMsgTransport.MessageTransport.Protocol.Ancillary.ICDCParticipantDevices.ICDCIdentityListDescription\x12\x19\n\x11recipientUserJIDs\x18\x03 \x03(\t\x1as\n\x1bICDCIdentityListDescription\x12\x0b\n\x03seq\x18\x01 \x01(\x05\x12\x15\n\rsigningDevice\x18\x02 \x01(\x0c\x12\x16\n\x0eunknownDevices\x18\x03 \x03(\x0c\x12\x18\n\x10unknownDeviceIDs\x18\x04 \x03(\x05\x1a\\\n\x1cSenderKeyDistributionMessage\x12\x0f\n\x07groupID\x18\x01 \x01(\t\x12+\n#axolotlSenderKeyDistributionMessage\x18\x02 \x01(\x0c\x1a\xaa\x01\n\x08Integral\x12\x0f\n\x07padding\x18\x01 \x01(\x0c\x12Q\n\x03\x44SM\x18\x02 \x01(\x0b\x32\x44.WAMsgTransport.MessageTransport.Protocol.Integral.DeviceSentMessage\x1a:\n\x11\x44\x65viceSentMessage\x12\x16\n\x0e\x64\x65stinationJID\x18\x01 \x01(\t\x12\r\n\x05phash\x18\x02 \x01(\t\"z\n\x12\x44\x65viceListMetadata\x12\x15\n\rsenderKeyHash\x18\x01 \x01(\x0c\x12\x17\n\x0fsenderTimestamp\x18\x02 \x01(\x04\x12\x18\n\x10recipientKeyHash\x18\x08 \x01(\x0c\x12\x1a\n\x12recipientTimestamp\x18\t \x01(\x04\x42*Z(go.mau.fi/whatsmeow/proto/waMsgTransport')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waMsgTransport.WAMsgTransport_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z(go.mau.fi/whatsmeow/proto/waMsgTransport'
  _globals['_MESSAGETRANSPORT']._serialized_start=81
  _globals['_MESSAGETRANSPORT']._serialized_end=1781
  _globals['_MESSAGETRANSPORT_PAYLOAD']._serialized_start=221
  _globals['_MESSAGETRANSPORT_PAYLOAD']._serialized_end=333
  _globals['_MESSAGETRANSPORT_PROTOCOL']._serialized_start=336
  _globals['_MESSAGETRANSPORT_PROTOCOL']._serialized_end=1781
  _globals['_MESSAGETRANSPORT_PROTOCOL_ANCILLARY']._serialized_start=491
  _globals['_MESSAGETRANSPORT_PROTOCOL_ANCILLARY']._serialized_end=1608
  _globals['_MESSAGETRANSPORT_PROTOCOL_ANCILLARY_BACKUPDIRECTIVE']._serialized_start=849
  _globals['_MESSAGETRANSPORT_PROTOCOL_ANCILLARY_BACKUPDIRECTIVE']._serialized_end=1081
  _globals['_MESSAGETRANSPORT_PROTOCOL_ANCILLARY_BACKUPDIRECTIVE_ACTIONTYPE']._serialized_start=1012
  _globals['_MESSAGETRANSPORT_PROTOCOL_ANCILLARY_BACKUPDIRECTIVE_ACTIONTYPE']._serialized_end=1081
  _globals['_MESSAGETRANSPORT_PROTOCOL_ANCILLARY_ICDCPARTICIPANTDEVICES']._serialized_start=1084
  _globals['_MESSAGETRANSPORT_PROTOCOL_ANCILLARY_ICDCPARTICIPANTDEVICES']._serialized_end=1514
  _globals['_MESSAGETRANSPORT_PROTOCOL_ANCILLARY_ICDCPARTICIPANTDEVICES_ICDCIDENTITYLISTDESCRIPTION']._serialized_start=1399
  _globals['_MESSAGETRANSPORT_PROTOCOL_ANCILLARY_ICDCPARTICIPANTDEVICES_ICDCIDENTITYLISTDESCRIPTION']._serialized_end=1514
  _globals['_MESSAGETRANSPORT_PROTOCOL_ANCILLARY_SENDERKEYDISTRIBUTIONMESSAGE']._serialized_start=1516
  _globals['_MESSAGETRANSPORT_PROTOCOL_ANCILLARY_SENDERKEYDISTRIBUTIONMESSAGE']._serialized_end=1608
  _globals['_MESSAGETRANSPORT_PROTOCOL_INTEGRAL']._serialized_start=1611
  _globals['_MESSAGETRANSPORT_PROTOCOL_INTEGRAL']._serialized_end=1781
  _globals['_MESSAGETRANSPORT_PROTOCOL_INTEGRAL_DEVICESENTMESSAGE']._serialized_start=1723
  _globals['_MESSAGETRANSPORT_PROTOCOL_INTEGRAL_DEVICESENTMESSAGE']._serialized_end=1781
  _globals['_DEVICELISTMETADATA']._serialized_start=1783
  _globals['_DEVICELISTMETADATA']._serialized_end=1905
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import waUserPassword.WAProtobufsUserPassword_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ChatLockSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HIDELOCKEDCHATS_FIELD_NUMBER: builtins.int
    SECRETCODE_FIELD_NUMBER: builtins.int
    hideLockedChats: builtins.bool
    @property
    def secretCode(self) -> waUserPassword.WAProtobufsUserPassword_pb2.UserPassword: ...
    def __init__(
        self,
        *,
        hideLockedChats: builtins.bool | None = ...,
        secretCode: waUserPassword.WAProtobufsUserPassword_pb2.UserPassword | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["hideLockedChats", b"hideLockedChats", "secretCode", b"secretCode"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hideLockedChats", b"hideLockedChats", "secretCode", b"secretCode"]) -> None: ...

global___ChatLockSettings = ChatLockSettings
